@@ -37,7 +37,7 @@
 #define __PLUGIN_CONFIG_H
 
 #define PLUGIN_NAME        "HELLO"
-#define PLUGIN_DESCRIPTION N_("Hello World!")
+#define PLUGIN_DESCRIPTION N_("Hello, World!")
 #define PLUGIN_VERSION     "1.0"
 #define PLUGIN_APPICON     "remmina-tool"
 #endif
