@@ -41,6 +41,7 @@
 #include <stdlib.h>
 #include "remmina.h"
 #include "remmina_main.h"
+#include "remmina_log.h"
 #include "remmina_pref.h"
 #include "remmina_widget_pool.h"
 #include "remmina_unlock.h"
@@ -55,6 +56,7 @@
 #include "remmina_icon.h"
 #include "remmina/remmina_trace_calls.h"
 #include "remmina_file_manager.h"
+#include "remmina_crypt.h"
 
 #ifdef SNAP_BUILD
 #   define ISSNAP "- SNAP Build -"
@@ -97,6 +99,9 @@ void remmina_exec_exitremmina()
 	/* Remove systray menu */
 	remmina_icon_destroy();
 
+	/* close/destroy main window struct and window */
+	remmina_main_destroy();
+
 	/* Exit from Remmina */
 	g_application_quit(g_application_get_default());
 }
@@ -205,21 +210,160 @@ static void remmina_exec_autostart_cb(RemminaFile *remminafile, gpointer user_da
 	TRACE_CALL(__func__);
 
 	if (remmina_file_get_int(remminafile, "enable-autostart", FALSE)) {
-		g_debug ("Profile %s is set to autostart", remminafile->filename);
+		REMMINA_DEBUG ("Profile %s is set to autostart", remminafile->filename);
 		rcw_open_from_filename(remminafile->filename);
 	}
 
 }
+
+static void remmina_exec_connect(const gchar *data)
+{
+	TRACE_CALL(__func__);
+
+	gchar *protocol;
+	gchar **protocolserver;
+	gchar *server;
+	RemminaFile *remminafile;
+	gchar **userat;
+	gchar **userpass;
+	gchar *user;
+	gchar *password;
+	gchar **domainuser;
+	gchar **serverquery;
+	gchar **querystring;
+	gchar **querystringpart;
+	gchar **querystringpartkv;
+	gchar *value;
+	gchar *temp;
+
+	protocol = NULL;
+	if (strncmp("rdp://", data, 6) == 0 || strncmp("RDP://", data, 6) == 0)
+		protocol = "RDP";
+	else if (strncmp("vnc://", data, 6) == 0 || strncmp("VNC://", data, 6) == 0)
+		protocol = "VNC";
+	else if (strncmp("ssh://", data, 6) == 0 || strncmp("SSH://", data, 6) == 0)
+		protocol = "SSH";
+	else if (strncmp("spice://", data, 8) == 0 || strncmp("SPICE://", data, 8) == 0)
+		protocol = "SPICE";
+
+	if (protocol == NULL) {
+		rcw_open_from_filename(data);
+		return;
+	}
+
+	protocolserver = g_strsplit(data, "://", 2);
+	server = g_strdup(protocolserver[1]);
+
+	// Support loading .remmina files using handler
+	if ((temp = strrchr(server, '.')) != NULL && g_strcmp0(temp + 1, "remmina") == 0) {
+		g_strfreev(protocolserver);
+		temp = g_uri_unescape_string(server, NULL);
+		g_free(server);
+		server = temp;
+		rcw_open_from_filename(server);
+		return;
+	}
+
+	remminafile = remmina_file_new();
+
+	// Check for username@server
+	if ((strcmp(protocol, "RDP") == 0 || strcmp(protocol, "VNC") == 0 || strcmp(protocol, "SSH") == 0) && strstr(server, "@") != NULL) {
+		userat = g_strsplit(server, "@", 2);
+
+		// Check for username:password
+		if (strstr(userat[0], ":") != NULL) {
+			userpass = g_strsplit(userat[0], ":", 2);
+			user = g_uri_unescape_string(userpass[0], NULL);
+			password = g_uri_unescape_string(userpass[1], NULL);
+
+			// Try to decrypt the password field if it contains =
+			temp = password != NULL && strrchr(password, '=') != NULL ? remmina_crypt_decrypt(password) : NULL;
+			if (temp != NULL) {
+				g_free(password);
+				password = temp;
+			}
+			remmina_file_set_string(remminafile, "password", password);
+			g_free(password);
+			g_strfreev(userpass);
+		} else {
+			user = g_uri_unescape_string(userat[0], NULL);
+		}
+
+		// Check for domain\user for RDP connections
+		if (strcmp(protocol, "RDP") == 0 && strstr(user, "\\") != NULL) {
+			domainuser = g_strsplit(user, "\\", 2);
+			remmina_file_set_string(remminafile, "domain", domainuser[0]);
+			g_free(user);
+			user = g_strdup(domainuser[1]);
+		}
+
+		remmina_file_set_string(remminafile, "username", user);
+		g_free(user);
+		g_free(server);
+		server = g_strdup(userat[1]);
+		g_strfreev(userat);
+	}
+
+	if (strcmp(protocol, "VNC") == 0 && strstr(server, "?") != NULL) {
+		// https://tools.ietf.org/html/rfc7869
+		// VncUsername, VncPassword and ColorLevel supported for vnc-params
+
+		// Check for query string parameters
+		serverquery = g_strsplit(server, "?", 2);
+		querystring = g_strsplit(serverquery[1], "&", -1);
+		for (querystringpart = querystring; *querystringpart; querystringpart++) {
+			if (strstr(*querystringpart, "=") == NULL)
+				continue;
+			querystringpartkv = g_strsplit(*querystringpart, "=", 2);
+			value = g_uri_unescape_string(querystringpartkv[1], NULL);
+			if (strcmp(querystringpartkv[0], "VncPassword") == 0) {
+				// Try to decrypt password field if it contains =
+				temp = value != NULL && strrchr(value, '=') != NULL ? remmina_crypt_decrypt(value) : NULL;
+				if (temp != NULL) {
+					g_free(value);
+					value = temp;
+				}
+				remmina_file_set_string(remminafile, "password", value);
+			} else if (strcmp(querystringpartkv[0], "VncUsername") == 0) {
+				remmina_file_set_string(remminafile, "username", value);
+			} else if (strcmp(querystringpartkv[0], "ColorLevel") == 0) {
+				remmina_file_set_string(remminafile, "colordepth", value);
+			}
+			g_free(value);
+			g_strfreev(querystringpartkv);
+		}
+		g_strfreev(querystring);
+		g_free(server);
+		server = g_strdup(serverquery[0]);
+		g_strfreev(serverquery);
+	}
+
+	// Unescape server
+	temp = g_uri_unescape_string(server, NULL);
+	g_free(server);
+	server = temp;
+
+	remmina_file_set_string(remminafile, "server", server);
+	remmina_file_set_string(remminafile, "name", server);
+	remmina_file_set_string(remminafile, "sound", "off");
+	remmina_file_set_string(remminafile, "protocol", protocol);
+	g_free(server);
+	g_strfreev(protocolserver);
+	rcw_open_from_file(remminafile);
+}
+
 void remmina_exec_command(RemminaCommandType command, const gchar* data)
 {
 	TRACE_CALL(__func__);
-	gchar* s1;
-	gchar* s2;
-	GtkWidget* widget;
-	GtkWindow* mainwindow;
-	GtkDialog* prefdialog;
-	RemminaEntryPlugin* plugin;
-
+	gchar *s1;
+	gchar *s2;
+	gchar *temp;
+	GtkWidget *widget;
+	GtkWindow *mainwindow;
+	GtkDialog *prefdialog;
+	RemminaEntryPlugin *plugin;
+    int i;
+    int ch;
 	mainwindow = remmina_main_get_window();
 
 	switch (command) {
@@ -270,7 +414,7 @@ void remmina_exec_command(RemminaCommandType command, const gchar* data)
 		 * we can implement multi profile connection:
 		 *    https://gitlab.com/Remmina/Remmina/issues/915
 		 */
-		rcw_open_from_filename(data);
+		remmina_exec_connect(data);
 		break;
 
 	case REMMINA_COMMAND_EDIT:
@@ -324,6 +468,30 @@ void remmina_exec_command(RemminaCommandType command, const gchar* data)
 		}
 		break;
 
+	case REMMINA_COMMAND_ENCRYPT_PASSWORD:
+		i = 0;
+		g_print("Enter the password you want to encrypt: ");
+		temp = (char *)g_malloc(255 * sizeof(char));
+		while ((ch = getchar()) != EOF && ch != '\n') {
+			if (i < 254) {
+				temp[i] = ch;
+				i++;
+			}
+		}
+		temp[i] = '\0';
+		s1 = remmina_crypt_encrypt(temp);
+		s2 = g_uri_escape_string(s1, NULL, TRUE);
+		g_print("\nEncrypted password: %s\n\n", s1);
+		g_print("Usage:\n");
+		g_print("rdp://username:%s@server\n", s1);
+		g_print("vnc://username:%s@server\n", s1);
+		g_print("vnc://server?VncUsername=user\\&VncPassword=%s\n", s2);
+		g_free(s1);
+		g_free(s2);
+		g_free(temp);
+		remmina_exec_exitremmina();
+		break;
+
 	case REMMINA_COMMAND_EXIT:
 		remmina_widget_pool_foreach(disable_rcw_delete_confirm_cb, NULL);
 		remmina_exec_exitremmina();
@@ -333,4 +501,3 @@ void remmina_exec_command(RemminaCommandType command, const gchar* data)
 		break;
 	}
 }
-
