@@ -49,7 +49,8 @@ typedef enum {
 	REMMINA_COMMAND_FULL_VERSION	=  8,
 	REMMINA_COMMAND_PLUGIN		=  9,
 	REMMINA_COMMAND_EXIT		= 10,
-	REMMINA_COMMAND_AUTOSTART	= 11
+	REMMINA_COMMAND_AUTOSTART	= 11,
+	REMMINA_COMMAND_ENCRYPT_PASSWORD	= 12
 } RemminaCommandType;
 
 typedef enum {
