@@ -151,6 +151,7 @@ struct _RemminaFTPClientPriv {
 	GtkWidget *file_action_widgets[10];
 	gboolean sensitive;
 	gboolean overwrite_all;
+	gboolean resume_all;
 };
 
 static gint remmina_ftp_client_taskid = 1;
@@ -265,16 +266,16 @@ static void remmina_ftp_client_cell_data_permission(GtkTreeViewColumn *col, GtkC
 
 	gtk_tree_model_get(model, iter, REMMINA_FTP_FILE_COLUMN_PERMISSION, &permission, -1);
 
-	buf[0] = (permission & 040000 ? 'd' : '-');
-	buf[1] = (permission & 0400 ? 'r' : '-');
-	buf[2] = (permission & 0200 ? 'w' : '-');
-	buf[3] = (permission & 0100 ? 'x' : '-');
-	buf[4] = (permission & 040 ? 'r' : '-');
-	buf[5] = (permission & 020 ? 'w' : '-');
-	buf[6] = (permission & 010 ? 'x' : '-');
-	buf[7] = (permission & 04 ? 'r' : '-');
-	buf[8] = (permission & 02 ? 'w' : '-');
-	buf[9] = (permission & 01 ? 'x' : '-');
+	buf[0] = ((permission & 040000) ? 'd' : '-');
+	buf[1] = ((permission & 0400) ? 'r' : '-');
+	buf[2] = ((permission & 0200) ? 'w' : '-');
+	buf[3] = ((permission & 0100) ? 'x' : '-');
+	buf[4] = ((permission & 040) ? 'r' : '-');
+	buf[5] = ((permission & 020) ? 'w' : '-');
+	buf[6] = ((permission & 010) ? 'x' : '-');
+	buf[7] = ((permission & 04) ? 'r' : '-');
+	buf[8] = ((permission & 02) ? 'w' : '-');
+	buf[9] = ((permission & 01) ? 'x' : '-');
 	buf[10] = '\0';
 
 	g_object_set(renderer, "text", buf, NULL);
@@ -837,6 +838,21 @@ gboolean remmina_ftp_client_get_overwrite_status(RemminaFTPClient *client)
 	return client->priv->overwrite_all;
 }
 
+/* Set the resume status */
+void remmina_ftp_client_set_resume_status(RemminaFTPClient *client, gboolean status)
+{
+	TRACE_CALL(__func__);
+	client->priv->resume_all = status;
+}
+
+/* Get the resume status */
+gboolean remmina_ftp_client_get_resume_status(RemminaFTPClient *client)
+{
+	TRACE_CALL(__func__);
+	return client->priv->resume_all;
+}
+
+
 static void remmina_ftp_client_init(RemminaFTPClient *client)
 {
 	TRACE_CALL(__func__);
@@ -854,6 +870,8 @@ static void remmina_ftp_client_init(RemminaFTPClient *client)
 
 	/* Initialize overwrite status to FALSE */
 	client->priv->overwrite_all = FALSE;
+	/* Initialize resume status to FALSE */
+	client->priv->resume_all = FALSE;
 
 	/* Main container */
 	gtk_widget_set_vexpand(GTK_WIDGET(client), TRUE);
