@@ -59,6 +59,8 @@ void remmina_plugin_ssh_vte_terminal_set_encoding_and_pty(VteTerminal *terminal,
 void remmina_plugin_ssh_vte_select_all(GtkMenuItem *menuitem, gpointer vte);
 void remmina_plugin_ssh_vte_copy_clipboard(GtkMenuItem *menuitem, gpointer vte);
 void remmina_plugin_ssh_vte_paste_clipboard(GtkMenuItem *menuitem, gpointer vte);
+void remmina_plugin_ssh_vte_decrease_font(GtkMenuItem *menuitem, gpointer vte);
+void remmina_plugin_ssh_vte_increase_font(GtkMenuItem *menuitem, gpointer vte);
 gboolean remmina_ssh_plugin_popup_menu(GtkWidget *widget, GdkEvent *event, GtkWidget *menu);
 #endif
 
